@@ -29,6 +29,9 @@ class LoopWindow(_LoopWindowGeneric):
             d'2
             e'4
         }
+
+        .. figure:: ../_images/image-LoopWindow-1.png
+
         >>> notes = looper()
         >>> staff = abjad.Staff(notes)
         >>> abjad.f(staff)
@@ -44,10 +47,12 @@ class LoopWindow(_LoopWindowGeneric):
             f'16
         }
 
-        The method ``get_current_window()`` will output the current window
-        without moving the head forwards.
+        .. figure:: ../_images/image-LoopWindow-2.png
 
-        >>> notes = looper.get_current_window()
+        The property ``current_window`` can be used to access the current
+        window without moving the head forwards.
+
+        >>> notes = looper.current_window()
         >>> staff = abjad.Staff(notes)
         >>> abjad.f(staff)
         \new Staff
@@ -62,6 +67,37 @@ class LoopWindow(_LoopWindowGeneric):
             f'16
         }
 
+        .. figure:: ../_images/image-LoopWindow-3.png
+
+    ..  container:: example
+
+        The very first call will output the input container without processing
+        it. To disable this behaviour and have the looping window move on the
+        very first call, initialise the class with the keyword argument
+        ``move_window_on_first_call`` set to ``True``.
+
+        >>> input_music = abjad.Container(r"c'4 d'2 e'4 f'2 ~ f'8 g'1")
+        >>> looper = auxjad.LoopWindow(input_music,
+        ...                            move_window_on_first_call=True,
+        ...                            )
+        >>> notes = looper()
+        >>> staff = abjad.Staff(notes)
+        >>> abjad.f(staff)
+        \new Staff
+        {
+            \time 4/4
+            c'8.
+            d'16
+            ~
+            d'4..
+            e'16
+            ~
+            e'8.
+            f'16
+        }
+
+        .. figure:: ../_images/image-LoopWindow-4.png
+
     ..  container:: example
 
         The optional arguments ``window_size`` and ``step_size`` can be used to
@@ -83,6 +119,9 @@ class LoopWindow(_LoopWindowGeneric):
             c'4
             d'2
         }
+
+        .. figure:: ../_images/image-LoopWindow-5.png
+
         >>> notes = looper()
         >>> staff = abjad.Staff(notes)
         >>> abjad.f(staff)
@@ -92,6 +131,8 @@ class LoopWindow(_LoopWindowGeneric):
             e'4
         }
 
+        .. figure:: ../_images/image-LoopWindow-6.png
+
     ..  container:: example
 
         The instances of ``LoopWindow`` can also be used as an iterator, which
@@ -104,62 +145,44 @@ class LoopWindow(_LoopWindowGeneric):
         ...                            window_size=(3, 4),
         ...                            step_size=(1, 8),
         ...                            )
+        >>> staff = abjad.Staff()
         >>> for window in looper:
-        ...     staff = abjad.Staff(window)
-        ...     abjad.f(staff)
+        ...     staff.append(window)
+        >>> abjad.f(staff)
         \new Staff
         {
             \time 3/4
             c'4
             d'2
-        }
-        \new Staff
-        {
             c'8
             d'8
             ~
             d'4.
             e'8
-        }
-        \new Staff
-        {
             d'2
             e'4
-        }
-        \new Staff
-        {
             d'4.
             e'8
             ~
             e'8
             r8
-        }
-        \new Staff
-        {
             d'4
             e'4
             r4
-        }
-        \new Staff
-        {
             d'8
             e'8
             ~
             e'8
             r4.
-        }
-        \new Staff
-        {
             e'4
             r2
-        }
-        \new Staff
-        {
             e'8
             r8
             r2
         }
 
+        .. figure:: ../_images/image-LoopWindow-7.png
+
     ..  container:: example
 
         This class can take many optional keyword arguments during its
@@ -202,16 +225,15 @@ class LoopWindow(_LoopWindowGeneric):
         >>> looper.omit_time_signature
         False
 
-        Use the ``set_`` methods below to change these values after
-        initialisation.
+        Use the properties below to change these values after initialisation.
 
-        >>> looper.set_window_size((5, 4))
-        >>> looper.set_step_size((1, 4))
-        >>> looper.set_max_steps(3)
-        >>> looper.set_repetition_chance(0.1)
-        >>> looper.set_forward_bias(0.8)
-        >>> looper.set_head_position(0)
-        >>> looper.set_omit_time_signature(True)
+        >>> looper.window_size = (5, 4)
+        >>> looper.step_size = (1, 4)
+        >>> looper.max_steps = 3
+        >>> looper.repetition_chance = 0.1
+        >>> looper.forward_bias = 0.8
+        >>> looper.head_position = 0
+        >>> looper.omit_time_signature = True
         >>> looper.window_size
         5/4
         >>> looper.step_size
@@ -257,6 +279,8 @@ class LoopWindow(_LoopWindowGeneric):
             r2
         }
 
+        .. figure:: ../_images/image-LoopWindow-8.png
+
     ..  container:: example
 
         When using ``output_all()``, set the keyword argument
@@ -293,6 +317,8 @@ class LoopWindow(_LoopWindowGeneric):
             r2
         }
 
+        .. figure:: ../_images/image-LoopWindow-9.png
+
     ..  container:: example
 
         To run through just part of the process and output it as a single
@@ -320,30 +346,30 @@ class LoopWindow(_LoopWindowGeneric):
             f'4
         }
 
+        .. figure:: ../_images/image-LoopWindow-10.png
+
     .. container:: example
 
         To change the size of the looping window after instantiation, use the
-        method ``set_window_size()``. In the example below, the initial window
-        is of size (4, 4), but changes to (3, 8) after three calls. Notice how
-        the very first call attaches a time signature equivalent to the window
-        size to the output window; subsequent calls will not have time
-        signatures unless the size of the looping window changes.
+        property ``window_size``. In the example below, the initial window is
+        of size (4, 4), but changes to (3, 8) after three calls. Notice how the
+        very first call attaches a time signature equivalent to the window size
+        to the output window; subsequent calls will not have time signatures
+        unless the size of the looping window changes.
 
         >>> input_music = abjad.Container(r"c'4 d'2 e'4 f'2 ~ f'8 g'1")
         >>> looper = auxjad.LoopWindow(input_music)
+        >>> staff = abjad.Staff()
         >>> for _ in range(3):
         ...     notes = looper()
-        ...     staff = abjad.Staff(notes)
-        ...     abjad.f(staff)
+        ...     staff.append(notes)
+        >>> abjad.f(staff)
         \new Staff
         {
             \time 4/4
             c'4
             d'2
             e'4
-        }
-        \new Staff
-        {
             c'8.
             d'16
             ~
@@ -352,9 +378,6 @@ class LoopWindow(_LoopWindowGeneric):
             ~
             e'8.
             f'16
-        }
-        \new Staff
-        {
             c'8
             d'8
             ~
@@ -364,11 +387,15 @@ class LoopWindow(_LoopWindowGeneric):
             e'8
             f'8
         }
-        >>> looper.set_window_size((3, 8))
+
+        .. figure:: ../_images/image-LoopWindow-11.png
+
+        >>> looper.window_size = (3, 8)
+        >>> staff = abjad.Staff()
         >>> for _ in range(3):
         ...     notes = looper()
-        ...     staff = abjad.Staff(notes)
-        ...     abjad.f(staff)
+        ...     staff.append(notes)
+        >>> abjad.f(staff)
         \new Staff
         {
             \time 3/8
@@ -376,19 +403,15 @@ class LoopWindow(_LoopWindowGeneric):
             d'16
             ~
             d'4
-        }
-        \new Staff
-        {
             d'4.
-        }
-        \new Staff
-        {
             d'4.
         }
 
+        .. figure:: ../_images/image-LoopWindow-12.png
+
         To disable time signatures altogether, initialise ``LoopWindow`` with
         the keyword argument ``omit_time_signature`` set to ``True`` (default
-        is ``False``), or use the ``set_omit_time_signature()`` method after
+        is ``False``), or use the ``omit_time_signature`` property after
         initialisation.
 
         >>> input_music = abjad.Container(r"c'4 d'2 e'4 f'2 ~ f'8 g'1")
@@ -403,6 +426,54 @@ class LoopWindow(_LoopWindowGeneric):
             e'4
         }
 
+        .. figure:: ../_images/image-LoopWindow-13.png
+
+    ..  container:: example
+
+        This class can handle dynamics and articulations too. When a leaf is
+        shortened by the looping window's movement, the dynamics and
+        articulations are still applied to it.
+
+        >>> input_music = abjad.Container(
+        ... r"c'4-.\p\< d'2--\f e'4->\ppp f'2 ~ f'8")
+        >>> looper = auxjad.LoopWindow(input_music)
+        >>> staff = abjad.Staff()
+        >>> for _ in range(2):
+        ...     music = looper()
+        ...     staff.append(music)
+        >>> abjad.f(staff)
+        \new Staff
+        {
+            \time 4/4
+            c'4
+            \p
+            - \staccato
+            \<
+            d'2
+            \f
+            - \tenuto
+            e'4
+            \ppp
+            - \accent
+            c'8.
+            \p
+            - \staccato
+            \<
+            d'16
+            \f
+            - \tenuto
+            ~
+            d'4..
+            e'16
+            \ppp
+            - \accent
+            ~
+            e'8.
+            f'16
+        }
+
+        .. figure:: ../_images/image-LoopWindow-14.png
+
     ..  container:: example
 
         This class can handle tuplets, but this functionality should be
@@ -444,6 +515,8 @@ class LoopWindow(_LoopWindowGeneric):
             ~
             d'2
         }
+
+        .. figure:: ../_images/image-LoopWindow-15.png
     """
 
     def __init__(self,
@@ -456,27 +529,38 @@ class LoopWindow(_LoopWindowGeneric):
                  forward_bias: float = 1.0,
                  head_position: (int, float, tuple, str, abjad.Duration) = 0,
                  omit_time_signature: bool = False,
+                 move_window_on_first_call: bool = False,
                  ):
         if not isinstance(container, abjad.Container):
             raise TypeError("'container' must be 'abjad.Container' or child "
                             "class")
         self._container = copy.deepcopy(container)
+        self._remove_all_time_signatures(self._container)
         self._container_length = abjad.inspect(container[:]).duration()
         self._new_time_signature = True
-        self.set_omit_time_signature(omit_time_signature)
+        self.omit_time_signature = omit_time_signature
         super().__init__(head_position,
                          window_size,
                          step_size,
                          max_steps,
                          repetition_chance,
                          forward_bias,
+                         move_window_on_first_call,
                          )
 
-    def set_head_position(self,
-                          head_position: tuple,
-                          ):
-        r"""Custom ``set_head_position()`` method since parent's method uses
-        integers as input, intead of tuples or ``abjad.Duration``.
+    def __repr__(self) -> str:
+        return str(abjad.f(self._container))
+
+    @property
+    def head_position(self) -> abjad.Duration:
+        return self._head_position
+
+    @head_position.setter
+    def head_position(self,
+                      head_position: (tuple, abjad.Duration),
+                      ):
+        r"""Custom setter method since parent's method uses integers as input,
+        intead of tuples or ``abjad.Duration``.
         """
         if not isinstance(head_position,
                           (int, float, tuple, str, abjad.Duration),
@@ -486,58 +570,73 @@ class LoopWindow(_LoopWindowGeneric):
         if abjad.Duration(head_position) >= self._container_length:
             raise ValueError("'head_position' must be smaller than the "
                              "length of 'container'")
-        self.head_position = abjad.Duration(head_position)
+        self._head_position = abjad.Duration(head_position)
 
-    def set_window_size(self,
-                        window_size: (tuple, abjad.Meter),
-                        ):
-        r"""Custom set_window_size() method since parent's method uses
-        integers as input, intead of tuples or abjad.Duration.
+    @property
+    def window_size(self) -> abjad.Meter:
+        return self._window_size
+
+    @window_size.setter
+    def window_size(self,
+                    window_size: (tuple, abjad.Meter),
+                    ):
+        r"""Custom setter method since parent's method uses integers as input,
+        intead of tuples or abjad.Duration.
         """
         if not isinstance(window_size,
                           (int, float, tuple, str, abjad.Meter),
                           ):
             raise TypeError("'window_size' must be 'tuple' or 'abjad.Meter'")
         if abjad.Meter(window_size).duration > self._container_length \
-                              - self.head_position:
+                              - self._head_position:
             raise ValueError("'window_size' must be smaller than or equal "
                              "to the length of 'container'")
-        if self._first_window or self.window_size.duration \
+        if self._first_window or self._window_size.duration \
                 != abjad.Meter(window_size).duration:
-            self.window_size = abjad.Meter(window_size)
+            self._window_size = abjad.Meter(window_size)
             self._new_time_signature = True
 
-    def set_step_size(self,
-                      step_size: tuple,
-                      ):
-        r"""Custom ``set_step_size()`` method since parent's method uses
-        integers as input, intead of tuples or ``abjad.Duration``.
+    @property
+    def step_size(self) -> abjad.Duration:
+        return self._step_size
+
+    @step_size.setter
+    def step_size(self,
+                  step_size: tuple,
+                  ):
+        r"""Custom setter method since parent's method uses integers as input,
+        intead of tuples or ``abjad.Duration``.
         """
         if not isinstance(step_size,
                           (int, float, tuple, str, abjad.Duration),
                           ):
             raise TypeError("'step_size' must be a 'tuple' or "
                             "'abjad.Duration'")
-        self.step_size = abjad.Duration(step_size)
+        self._step_size = abjad.Duration(step_size)
 
-    def set_omit_time_signature(self,
-                                omit_time_signature: bool,
-                                ):
+    @property
+    def omit_time_signature(self) -> list:
+        return self._omit_time_signature
+
+    @omit_time_signature.setter
+    def omit_time_signature(self,
+                            omit_time_signature: bool,
+                            ):
         if not isinstance(omit_time_signature, bool):
             raise TypeError("'omit_time_signature' must be 'bool'")
-        self.omit_time_signature = omit_time_signature
+        self._omit_time_signature = omit_time_signature
 
     def _done(self) -> bool:
         r"""Custom ``_done`` method since parent's method uses the ``__len__``
         method, which cannot be used for non-integer values such as
         ``abjad.Duration``.
         """
-        return self.head_position >= self._container_length or \
-            self.head_position < 0
+        return self._head_position >= self._container_length or \
+            self._head_position < 0
 
-    def _slice_container(self) -> abjad.Selection:
-        head = self.head_position
-        window_size = self.window_size
+    def _slice_container(self):
+        head = self._head_position
+        window_size = self._window_size
         dummy_container = copy.deepcopy(self._container)
         # splitting leaves at both slicing points
         if head > abjad.Duration(0):
@@ -549,15 +648,23 @@ class LoopWindow(_LoopWindowGeneric):
         # finding start and end indeces for the window
         for start in range(len(dummy_container)):
             if abjad.inspect(dummy_container[:start + 1]).duration() > head:
-                abjad.detach(abjad.Tie(), dummy_container[start - 1])
                 break
         for end in range(start + 1, len(dummy_container)):
             if abjad.inspect(dummy_container[start : end]).duration() == \
                     window_size.duration:
-                abjad.detach(abjad.Tie(), dummy_container[end - 1])
                 break
         else:
             end = len(dummy_container)
+        # passing on indicators from the head of an initial splitted leaf
+        for index in range(start - 1, -1, -1):
+            if abjad.inspect(dummy_container[index]).indicator(abjad.Tie):
+                if index == 0 or not abjad.inspect(dummy_container[index - 1]).indicator(abjad.Tie):
+                    for indicator in abjad.inspect(dummy_container[index]).indicators():
+                        if not isinstance(indicator, (abjad.TimeSignature, abjad.Tie)):
+                            abjad.attach(indicator, dummy_container[start])
+        # removing ties generated by the split mutation
+        abjad.detach(abjad.Tie(), dummy_container[start - 1])
+        abjad.detach(abjad.Tie(), dummy_container[end - 1])
         # appending rests if necessary
         container_dur = abjad.inspect(dummy_container[start : end]).duration()
         if container_dur < window_size.duration:
@@ -570,7 +677,7 @@ class LoopWindow(_LoopWindowGeneric):
             abjad.mutate(dummy_container[start : end]).copy()
         )
         abjad.mutate(dummy_container[:]).rewrite_meter(window_size)
-        if self._new_time_signature and not self.omit_time_signature:
+        if self._new_time_signature and not self._omit_time_signature:
             abjad.attach(abjad.TimeSignature(window_size),
                          abjad.select(dummy_container).leaves()[0],
                          )
