@@ -38,10 +38,25 @@ class LoopWindowByList(_LoopWindowGeneric):
         >>> looper()
         ['B', 'C', 'D']
 
-        The method get_current_window() will output the current window without
-        moving the head forwards.
+        The property ``current_window`` can be used to access the current
+        window without moving the head forwards.
 
-        >>> looper.get_current_window()
+        >>> looper.current_window
+        ['B', 'C', 'D']
+
+    ..  container:: example
+
+        The very first call will output the input list without processing
+        it. To disable this behaviour and have the looping window move on the
+        very first call, initialise the class with the keyword argument
+        ``move_window_on_first_call`` set to ``True``.
+
+        >>> input_list = ['A', 'B', 'C', 'D', 'E', 'F']
+        >>> looper = auxjad.LoopWindowByList(input_list,
+        ...                                  window_size=3,
+        ...                                  move_window_on_first_call=True,
+        ...                                  )
+        >>> looper()
         ['B', 'C', 'D']
 
     ..  container:: example
@@ -71,7 +86,7 @@ class LoopWindowByList(_LoopWindowGeneric):
         ranging between 1 and the input value (default is also 1).
         ``repetition_chance`` sets the chance of a window result repeating
         itself (that is, the window not moving forwards when called). It should
-        range from 0.0 to 1.0 (default 0.0, i.e. no repetition). 
+        range from 0.0 to 1.0 (default 0.0, i.e. no repetition).
         ``forward_bias`` sets the chance of the window moving forward instead
         of backwards. It should range from 0.0 to 1.0 (default 1.0, which means
         the window can only move forwards. A value of 0.5 gives 50% chance of
@@ -101,15 +116,14 @@ class LoopWindowByList(_LoopWindowGeneric):
         >>> looper.head_position
         0
 
-        Use the ``set_`` methods below to change these values after
-        initialisation.
+        Use the properties below to change these values after initialisation.
 
-        >>> looper.set_window_size(2)
-        >>> looper.set_step_size(2)
-        >>> looper.set_max_steps(3)
-        >>> looper.set_repetition_chance(0.1)
-        >>> looper.set_forward_bias(0.8)
-        >>> looper.set_head_position(2)
+        >>> looper.window_size = 2
+        >>> looper.step_size = 2
+        >>> looper.max_steps = 3
+        >>> looper.repetition_chance = 0.1
+        >>> looper.forward_bias = 0.8
+        >>> looper.head_position = 2
         >>> looper.window_size
         2
         >>> looper.step_size
@@ -157,19 +171,19 @@ class LoopWindowByList(_LoopWindowGeneric):
 
     .. container:: example
 
-        To change the size of the window after instantiation, use the method
-        ``set_window_size()``. In the example below, the initial window is of
-        size 3, and so the first call of the looper object outputs the first,
-        second, and third elements of the list. The window size is then set to
-        4, and the looper is called again, moving to the element in the next
-        position, thus outputting the second, third, fourth, and fifth
+        To change the size of the looping window after instantiation, use the
+        property ``window_size``. In the example below, the initial window is
+        of size 3, and so the first call of the looper object outputs the
+        first, second, and third elements of the list. The window size is then
+        set to 4, and the looper is called again, moving to the element in the
+        next position, thus outputting the second, third, fourth, and fifth
         elements.
 
         >>> input_list = ['A', 'B', 'C', 'D', 'E', 'F']
         >>> looper = auxjad.LoopWindowByList(input_list, window_size=3)
         >>> looper()
         ['A', 'B', 'C']
-        >>> looper.set_window_size(4)
+        >>> looper.window_size = 4
         >>> looper()
         ['B', 'C', 'D', 'E']
 
@@ -191,7 +205,7 @@ class LoopWindowByList(_LoopWindowGeneric):
         >>> input_list = [
         ...     abjad.Container(r"c'4 d'4 e'4 f'4"),
         ...     abjad.Container(r"fs'1"),
-        ...     abjad.Container(r"r2 bf2"),
+        ...     abjad.Container(r"r2 bf4 c'4"),
         ...     abjad.Container(r"c''2. r4"),
         ... ]
         >>> looper = auxjad.LoopWindowByList(input_list, window_size=3)
@@ -212,14 +226,16 @@ class LoopWindowByList(_LoopWindowGeneric):
             }
             {
                 r2
-                bf2
+                bf4
+                c'4
             }
             {
                 fs'1
             }
             {
                 r2
-                bf2
+                bf4
+                c'4
             }
             {
                 c''2.
@@ -227,7 +243,8 @@ class LoopWindowByList(_LoopWindowGeneric):
             }
             {
                 r2
-                bf2
+                bf4
+                c'4
             }
             {
                 c''2.
@@ -238,6 +255,8 @@ class LoopWindowByList(_LoopWindowGeneric):
                 r4
             }
         }
+
+        .. figure:: ../_images/image-LoopWindowByList-1.png
     """
 
     def __init__(self,
@@ -249,6 +268,7 @@ class LoopWindowByList(_LoopWindowGeneric):
                  repetition_chance: float = 0.0,
                  forward_bias: float = 1.0,
                  head_position: int = 0,
+                 move_window_on_first_call: bool = False,
                  ):
         if not isinstance(container, list):
             raise TypeError("'container' must be 'list'")
@@ -259,8 +279,12 @@ class LoopWindowByList(_LoopWindowGeneric):
                          max_steps,
                          repetition_chance,
                          forward_bias,
+                         move_window_on_first_call,
                          )
 
+    def __repr__(self) -> str:
+        return str(self._container)
+
     def __len__(self) -> int:
         return len(self._container)
 
@@ -290,12 +314,16 @@ class LoopWindowByList(_LoopWindowGeneric):
         r"""Custom output_n() method since parent's method outputs an
         ``abjad.Selection``.
         """
+        if not isinstance(n, int):
+            raise TypeError("'n' must be 'int'")
+        if n < 0:
+            raise ValueError("'n' must be a positive 'int'")
         dummy_container = []
         for _ in range(n):
             dummy_container.extend(self.__call__())
         return dummy_container[:]
 
-    def _slice_container(self) -> list:
+    def _slice_container(self):
         start = self.head_position
         end = self.head_position + self.window_size
         self._current_window = self._container[start:end]
