@@ -1,15 +1,22 @@
 from .are_containers_equal import are_containers_equal
 from .are_leaves_tieable import are_leaves_tieable
+from .ArtificialHarmonic import ArtificialHarmonic
 from .CartographyContainer import CartographyContainer
 from .close_container import close_container
 from .fill_with_rests import fill_with_rests
+from .HarmonicNote import HarmonicNote
 from .is_container_full import is_container_full
 from .LeafDynMaker import LeafDynMaker
+from .LeafShuffler import LeafShuffler
 from .LoopWindow import LoopWindow
 from .LoopWindowByElements import LoopWindowByElements
 from .LoopWindowByList import LoopWindowByList
 from .remove_repeated_dynamics import remove_repeated_dynamics
 from .remove_repeated_time_signatures import remove_repeated_time_signatures
+from .repeat_container import repeat_container
+from .respell_container import respell_container
+from .respell_chord import respell_chord
+from .rests_to_multimeasure_rest import rests_to_multimeasure_rest
 from .simplified_time_signature_ratio import simplified_time_signature_ratio
 from .sync_containers import sync_containers
 from .TenneysContainer import TenneysContainer
