@@ -22,10 +22,11 @@ def remove_repeated_dynamics(container: abjad.Container,
         When two consecutive leaves have identical dynamics, the second
         one is removed:
 
-        >>> staff = abjad.Staff(r"c'4\pp d'8\pp | c'4\f d'8\f")
+        >>> staff = abjad.Staff(r"\time 3/8 c'4\pp d'8\pp | c'4\f d'8\f")
         >>> abjad.f(staff)
         \new Staff
         {
+            \time 3/8
             c'4
             \pp
             d'8
@@ -35,10 +36,14 @@ def remove_repeated_dynamics(container: abjad.Container,
             d'8
             \f
         }
+
+        .. figure:: ../_images/image-remove_repeated_dynamics-1.png
+
         >>> auxjad.remove_repeated_dynamics(staff)
         >>> abjad.f(staff)
         \new Staff
         {
+            \time 3/8
             c'4
             \pp
             d'8
@@ -47,15 +52,18 @@ def remove_repeated_dynamics(container: abjad.Container,
             d'8
         }
 
+        .. figure:: ../_images/image-remove_repeated_dynamics-2.png
+
     ..  container:: example
 
         The function also removes dynamics that are separated by an arbitrary
         number of leaves without dynamics:
 
-        >>> staff = abjad.Staff(r"c'4\p d'8 | e'4.\p | c'4\p d'8\f")
+        >>> staff = abjad.Staff(r"\time 3/8 c'4\p d'8 | e'4.\p | c'4\p d'8\f")
         >>> abjad.f(staff)
         \new Staff
         {
+            \time 3/8
             c'4
             \p
             d'8
@@ -66,10 +74,14 @@ def remove_repeated_dynamics(container: abjad.Container,
             d'8
             \f
         }
+
+        .. figure:: ../_images/image-remove_repeated_dynamics-3.png
+
         >>> auxjad.remove_repeated_dynamics(staff)
         >>> abjad.f(staff)
         \new Staff
         {
+            \time 3/8
             c'4
             \p
             d'8
@@ -79,6 +91,8 @@ def remove_repeated_dynamics(container: abjad.Container,
             \f
         }
 
+        .. figure:: ../_images/image-remove_repeated_dynamics-4.png
+
     ..  container:: example
 
         The input container can also handle subcontainers:
@@ -104,6 +118,9 @@ def remove_repeated_dynamics(container: abjad.Container,
                 b2
             }
         }
+
+        .. figure:: ../_images/image-remove_repeated_dynamics-5.png
+
         >>> auxjad.remove_repeated_dynamics(staff)
         >>> abjad.f(staff)
         \new Staff
@@ -118,73 +135,93 @@ def remove_repeated_dynamics(container: abjad.Container,
             }
         }
 
+        .. figure:: ../_images/image-remove_repeated_dynamics-6.png
+
     ..  container:: example
 
         By default, repeated dynamics with hairpins in between are not removed,
         but consecutive ones will.
 
-        >>> staff = abjad.Staff(r"c'4\pp\< d'8\f\> | c'4\f d'8\f")
+        >>> staff = abjad.Staff(r"c'2\p\< d'2\f\> | c'2\f d'2\f | e'1\p")
         >>> abjad.f(staff)
         \new Staff
         {
-            c'4
-            \pp
+            c'1
+            \p
             \<
-            d'8
+            d'1
             \f
             \>
-            c'4
+            c'1
             \f
-            d'8
+            d'1
             \f
+            e'1
+            \p
         }
+
+        .. figure:: ../_images/image-remove_repeated_dynamics-7.png
+
         >>> auxjad.remove_repeated_dynamics(staff)
         >>> abjad.f(staff)
         \new Staff
         {
-            c'4
-            \pp
+            c'1
+            \p
             \<
-            d'8
+            d'1
             \f
             \>
-            c'4
+            c'1
             \f
-            d'8
+            d'1
+            e'1
+            \p
         }
 
+        .. figure:: ../_images/image-remove_repeated_dynamics-8.png
+
         To override the previous behaviour, set ``ignore_hairpins=True`` and
         hairpins will be ignored.
 
-        >>> staff = abjad.Staff(r"c'4\pp\< d'8\f\> | c'4\f d'8\f")
+        >>> staff = abjad.Staff(r"c'2\p\< d'2\f\> | c'2\f d'2\f | e'1\p")
         >>> abjad.f(staff)
         \new Staff
         {
-            c'4
-            \pp
+            c'1
+            \p
             \<
-            d'8
+            d'1
             \f
             \>
-            c'4
+            c'1
             \f
-            d'8
+            d'1
             \f
+            e'1
+            \p
         }
+
+        .. figure:: ../_images/image-remove_repeated_dynamics-9.png
+
         >>> auxjad.remove_repeated_dynamics(staff, ignore_hairpins=True)
         >>> abjad.f(staff)
         \new Staff
         {
-            c'4
-            \pp
+            c'1
+            \p
             \<
-            d'8
+            d'1
             \f
             \>
-            c'4
-            d'8
+            c'1
+            d'1
+            e'1
+            \p
         }
 
+        .. figure:: ../_images/image-remove_repeated_dynamics-10.png
+
     ..  container:: example
 
         By default, rests are treated just like any other leaf and thus notes
@@ -202,6 +239,8 @@ def remove_repeated_dynamics(container: abjad.Container,
             c'4
         }
 
+        .. figure:: ../_images/image-remove_repeated_dynamics-11.png
+
         To override the previous behaviour, set ``reset_after_rests=True`` and
         dynamics will always be restated after a rest.
 
@@ -217,6 +256,8 @@ def remove_repeated_dynamics(container: abjad.Container,
             \pp
         }
 
+        .. figure:: ../_images/image-remove_repeated_dynamics-12.png
+
     ..  container:: example
 
         The argument ``reset_after_rests`` takes not only boolean values but
@@ -239,6 +280,8 @@ def remove_repeated_dynamics(container: abjad.Container,
             c'4
         }
 
+        .. figure:: ../_images/image-remove_repeated_dynamics-13.png
+
         But setting the duration to 2/4 forces the dynamic to be restated.
 
         >>> staff = abjad.Staff(r"c'4\pp r2. | c'4\pp")
@@ -253,11 +296,13 @@ def remove_repeated_dynamics(container: abjad.Container,
             \pp
         }
 
+        .. figure:: ../_images/image-remove_repeated_dynamics-14.png
+
     ..  container:: example
 
         The function also handles measure rests with ``reset_after_rests``.
 
-        >>> staff = abjad.Staff(r"c'4\pp r2. | R1 | c'4\pp")
+        >>> staff = abjad.Staff(r"c'4\pp r2. | c'4\pp r2. |R1 | c'4\pp")
         >>> auxjad.remove_repeated_dynamics(
         ...     staff,
         ...     reset_after_rests=abjad.Duration(4, 4),
@@ -268,10 +313,14 @@ def remove_repeated_dynamics(container: abjad.Container,
             c'4
             \pp
             r2.
+            c'4
+            r2.
             R1
             c'4
             \pp
         }
+
+        .. figure:: ../_images/image-remove_repeated_dynamics-15.png
     """
     if not isinstance(container, abjad.Container):
         raise TypeError("'container' must be 'abjad.Container' or child class")
